$Title Minimizing the investment cost of a subsea separation system.

$Ontext
Optimization of the model presented in the report: "Superstructure
optimization of a subsea separation system".
Objective: Find the combination of process units that minimizes the investment
costs and satisfies the the specifications of the process.
$Offtext

*Defining a symbol for an end of line comment.
$eolcom ->
*.

*Defining the sets
Set
         i mass flow index /i1*i17/
         j bin var index /j1*j12/
         k eq number /k1*k13/;

*Parameters for the model
Parameters
         G gas stream /12720/
         O oil stream /206200/
         U upper limit for mass flows /250000/
         b(k) RHS coeff for mass balances /set.k 0/

*Fixed costs for the units                              Binary variables
         C_c Cost for cooler /423885/                   -> y1.
         C_s Cost for separator /1003096/               -> y2.
         C_k Cost for compressor /22760726/             -> y3.
         C_p Cost for pump / 3045354/                   -> y4.
         C_MP Cost for multiphase pump /16000000/       -> y5.
         C_fg Cost for flowline gas /93675000/          -> y6.
         C_rg Cost for riser gas /714000/               -> y7.
         C_fm Cost for flowline multiphase /154500000/  -> y8.
         C_rm Cost for riser multiphase /2177700/       -> y9.
         C_ts Cost for toptside separator /462183/      -> y10.
         C_fo Cost for flowline oil /129165000/         -> y11.
         C_ro Cost for riser oil /1438200/;             -> y12.


*Assigning numbers to the vector.
b('k1') = G;
b('k7') = -O;

Table A(k,i)
         i1  i2  i3  i4  i5  i6  i7  i8  i9  i10 i11 i12 i13 i14 i15 i16 i17
   k1    1   0   0   0   0   0   1   0   0   0   0   0   0   0   0   0   0
   k2    1  -1   0   0   0   0   0   0   0   0   0   0   0   0   0   0   0
   k3    0  0.05 0   0   0   0   0  -1   0   0   0   0   0   0   0   0   0
   k4    0  -1   1   0   0   0   0   1   0   0   0   0   0   0   0   0   0
   k5    0   0  -1   1   0   0   0   0   0   0   0   0   0   0   0   0   0
   k6    0   0   0  -1   1   1   0   0   0   0   0   0   0   0   0   0   0
   k7    0   0   0   0   0   0   1   1  -1   0   0   0   0   0   0   0   0
   k8    0   0   0   0   0   0   0   0  -1   1   1   0   0   0   0   0   0
   k9    0   0   0   0   0   0   0   0   0  -1   0   1   0   0   0   0   0
   k10   0   0   0   0   0   0   0   0   0   0  -1   0   1   0   0   0   0
   k11   0   0   0   0   0   0   0   0   0   0   0   1   1  -1   0   0   0
   k12   0   0   0   0   0   0   0   0   0   0   0   0   0  -1   1   1   0
   k13   0   0   0   0   0   1   0   0   0   0   0   0   0   0   0   1  -1;

*Variables
Positive variables x(i) mass flows;

Binary variables y(j);

Variable c0 investment
         inv_cost investment cost;

*Declaring equations
Equations
         obj objective function
         MB(k) mass balances
         q1 flow to zero
         q2 flow to zero
         q3 flow to zero
         q4 flow to zero
         q5 flow to zero
         q6 flow to zero
         q7 flow to zero
         q8 flow to zero
         l1 logic eq 1
         l2 logic eq 2
         l3 logic eq 3
         l4 logic eq 4
         l5 logic eq 5
         l6 logic eq 6
         l7 logic eq 7
         l8 logic eq 8
         l9 logic eq 9
         l10 logic eq 10
         l11 logic eq 11;

*Defining the equations
obj..    inv_cost =e= 1E-6*(C_c*y('j1') + C_s*y('j2') + C_k*y('j3') +
         C_p*y('j4')+ C_MP* y('j5') + C_fg*y('j6') + C_rg*y('j7') +
         C_fm*y('j8') + C_rm*y('j9') + C_ts*y('j10') +
         C_fo*y('j11') + C_ro*y('j12'));
MB(k)..  sum(i,A(k,i)*x(i)) =e= b(k);                    ->Mass balances.
q1..     x('i1') - U*y('j1') =l= 0;
q2..     x('i7') - U*y('j5') =l= 0;
q3..     x('i10') - U*y('j5') =l= 0;
q4..     x('i11') - U*y('j4') =l= 0;
q5..     x('i5') - U*y('j6') =l= 0;
q6..     x('i6') - U*y('j8') =l= 0;
q7..     x('i15') - U*y('j11') =l= 0;
q8..     x('i16') - U*y('j8') =l= 0;
l1..     y('j4') + y('j5') =e= 1;
l2..     y('j6') + y('j8') =e= 1;
l3..     y('j5') - y('j8') =l= 0;
l4..     y('j1') - y('j2') =e= 0;
l5..     y('j2') - y('j3') =e= 0;
l6..     y('j3') - y('j4') =e= 0;
l7..     y('j6') - y('j7') =e= 0;
l8..     y('j7') - y('j11') =e= 0;
l9..     y('j11') - y('j12') =e= 0;
l10..    y('j8') - y('j9') =e= 0;
l11..    y('j9') - y('j10') =e= 0;

Model Subpro /all/;

Option optcr=0.0;        ->Zero optimality gap.
Option reslim=9E9;       ->Increased time limit.
option mip = cplex;

*Solving the model
Solve Subpro using MIP minimizing inv_cost;

display y.l;






