$Title Maxiizing the NPV of a subsea separation system.

$Ontext
Optimization of the model presented in the report: "Superstructure
optimization of a subsea separation system".
Objective: Find the combination of process units that maximizes the NPV and
satisfies the the specifications of the process.
$Offtext

*Defining a symbol for an end of line comment.
$eolcom ->
*.

*Defining the sets
Set
         i mass flow index /i1*i17/
         j bin var index /j1*j12/
         k eq number /k1*k13/
         t years /1*10/;

*Parameters for the model
Parameters
         U upper limit for mass flows /300000/
         b(k) RHS coeff for mass balances /set.k 0/

*Early production
*        G gas stream /12720/
*        O oil stream /206200/

*Late production
         G gas stream /929/
         O oil stream /11580/


*Fixed costs for the units                              Binary variables
*        C_c Cost for cooler /0.750855/                  -> y1.
         C_s Cost for separator /1.003096/               -> y2.
*        C_k Cost for compressor /22.760726/             -> y3.
*        C_p Cost for pump /0.222857/                    -> y4.
         C_MP Cost for multiphase pump /16.000000/       -> y5.
         C_fg Cost for flowline gas /93.675000/          -> y6.
         C_rg Cost for riser gas /0.714000/              -> y7.
         C_fm Cost for flowline multiphase /154.500000/  -> y8.
         C_rm Cost for riser multiphase /2.177700/       -> y9.
         C_ts Cost for toptside separator /0.462183/     -> y10.
         C_fo Cost for flowline oil /129.165000/         -> y11.
         C_ro Cost for riser oil /1.438200/              -> y12.

*Economic factors
         f_inst installation factor /4.208/
         f_sub factor for installation subsea /3/
         f_I scaling economics for inflation /1.1035/

*compressor
         p1 pressure in  /6500/
         p2 pressure out /30500/
         gamma Cp over Cv /1.557488545/
         d_gas density /53.44791051/
         eff_k effectivity /0.75/

*oil pump
         d_oil density of oil /844/
         dp pressure difference /30000000/
         eff_p adiabatic efficiency pump /0.75/

*Multiphase pump
         H head converted from differential pressure /2713.25/
         eff_MP multiphase pump efficiency /0.75/

*Heat exchanger
         LMTD logarithmic mean temp difference /19.6/
         dT temperature difference (out-in) /2.5/
         Cp_g Heat capacity of gas /2681/
         U_h heat transfer coefficient /20/

*cost and plant data
         r discount rate /0.1/
         p_bbl price per barrel oil /57.30/
         p_g price natural gas /2.61/
         bbl_m3 barrels per cubic meter /6.29/
         MMBTU_m3 MMBTU per cubic meter /0.0354/
         h_y operating hours per year /8000/
         p_e price for electricity /0.09/;


*Assigning numbers to the vector
b('k1') = G;
b('k7') = -O;

Table A(k,i)
         i1  i2  i3  i4  i5  i6  i7  i8  i9  i10 i11 i12 i13 i14 i15 i16 i17
   k1    1   0   0   0   0   0   1   0   0   0   0   0   0   0   0   0   0
   k2    1  -1   0   0   0   0   0   0   0   0   0   0   0   0   0   0   0
   k3    0  0.05 0   0   0   0   0  -1   0   0   0   0   0   0   0   0   0
   k4    0  -1   1   0   0   0   0   1   0   0   0   0   0   0   0   0   0
   k5    0   0  -1   1   0   0   0   0   0   0   0   0   0   0   0   0   0
   k6    0   0   0  -1   1   1   0   0   0   0   0   0   0   0   0   0   0
   k7    0   0   0   0   0   0   1   1  -1   0   0   0   0   0   0   0   0
   k8    0   0   0   0   0   0   0   0  -1   1   1   0   0   0   0   0   0
   k9    0   0   0   0   0   0   0   0   0  -1   0   1   0   0   0   0   0
   k10   0   0   0   0   0   0   0   0   0   0  -1   0   1   0   0   0   0
   k11   0   0   0   0   0   0   0   0   0   0   0   1   1  -1   0   0   0
   k12   0   0   0   0   0   0   0   0   0   0   0   0   0  -1   1   1   0
   k13   0   0   0   0   0   1   0   0   0   0   0   0   0   0   0   1  -1;

*Variables
Positive variables x(i) mass flows;

Binary variables y(j);

Variable NPV net present value
         c0 investment cost
         CF cash flow
         P_k power consumption of compressor
         C_k cost of compressor
         P_p power consumption of pump
         C_p cost of pump
         C_pmo cost of pump motor
         P_MP power consumption multiphase pump
         Area heat exchange area
         C_c cost of cooler;


*Declaring equations
Equations
         obj objective function
         cinv investment costs
         rev revenue
         MB(k) mass balances
         pwr_k power consuption of compressor
         Ck cost of compressor
         pwr_p power consumption of pump
         Cp cost of pump
         Cpmo cost of pump motor
         pwr_MP power consumption multiphase pump
         Aeq Heat transfer area
         Cc cost of cooler
         q1 flow to zero
         q2 flow to zero
         q3 flow to zero
         q4 flow to zero
         q5 flow to zero
         q6 flow to zero
         q7 flow to zero
         q8 flow to zero
         l1 logic eq 1
         l2 logic eq 2
         l3 logic eq 3
         l4 logic eq 4
         l5 logic eq 5
         l6 logic eq 6
         l7 logic eq 7
         l8 logic eq 8
         l9 logic eq 9
         l10 logic eq 10
         l11 logic eq 11;

*Defining the equations
obj..    NPV =e= -C0 + sum(t,CF/((1+r)**ord(t)));
cinv..   C0 =e= C_c + C_s*y('j2') + C_k + C_p + C_MP* y('j5') + C_fg*y('j6')
          + C_rg*y('j7') + C_fm*y('j8') + C_rm*y('j9') + C_ts*y('j10') +
          C_fo*y('j11') + C_ro*y('j12');
rev..    CF =e= (1/1000000)*((O*bbl_m3*p_bbl/d_oil + G*MMBTU_m3*p_g/d_gas)*h_y
          - (P_k+P_p+P_MP)*h_y*p_e);
pwr_k..  P_k =e= p1*(x('i3')/(d_gas*3600))*(gamma/(gamma-1))*
         ((p2/p1)**((gamma-1)/gamma)-1)/eff_k;
Ck..     C_k =e= (1/1000000)*(490000*y('j3') + 16800*P_k**0.6)*
         f_inst*f_sub*f_I;
pwr_p..  P_p =e= dp*x('i11')/(d_oil*3600*eff_p*1000);
Cp..     C_p =e= C_pmo + (1/1000000)*(6900*y('j4') +
         206*(x('i11')/(d_oil*3.6))**0.9)*f_inst*f_sub*f_I;
Cpmo..   C_pmo =e= (1/1000000)*(-950*y('j4') + 1770*P_p**0.6)*
         f_inst*f_sub*f_I;
pwr_MP.. P_MP =e= x('i10')*9.81*h/(3600000*eff_MP);
Aeq..    Area =e= x('i1')*dT*Cp_g/(3600*U_h*LMTD);
Cc..     C_c =e= (1/1000000)*(24000*y('j1')+46*Area**1.2)*f_inst*f_sub*f_I;
MB(k)..  sum(i,A(k,i)*x(i)) =e= b(k);                    ->Mass balances.
q1..     x('i1') - U*y('j1') =l= 0;
q2..     x('i7') - U*y('j5') =l= 0;
q3..     x('i10') - U*y('j5') =l= 0;
q4..     x('i11') - U*y('j4') =l= 0;
q5..     x('i5') - U*y('j6') =l= 0;
q6..     x('i6') - U*y('j8') =l= 0;
q7..     x('i15') - U*y('j11') =l= 0;
q8..     x('i16') - U*y('j8') =l= 0;
l1..     y('j4') + y('j5') =e= 1;
l2..     y('j6') + y('j8') =e= 1;
l3..     y('j5') - y('j8') =l= 0;
l4..     y('j1') - y('j2') =e= 0;
l5..     y('j2') - y('j3') =e= 0;
l6..     y('j3') - y('j4') =e= 0;
l7..     y('j6') - y('j7') =e= 0;
l8..     y('j7') - y('j11') =e= 0;
l9..     y('j11') - y('j12') =e= 0;
l10..    y('j8') - y('j9') =e= 0;
l11..    y('j9') - y('j10') =e= 0;

C_pmo.up = 1000;
Model Subpro /all/;

Option optcr=0.0;        ->Zero optimality gap.
Option reslim=9E9;       ->Increased time limit.

*option sysout = on ;
option minlp = dicopt;
*option nlp = conopt;
*option mip = gurobi;

*solving the model
Solve Subpro using MINLP maximizing NPV;

display y.l;






